@@ -1,7 +1,5 @@
 # !/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from inspect import stack
-from re import split as re_split
 from typing import List, Optional
 
 from ._utils import object_class
@@ -128,18 +126,6 @@ apis = {
 }
 
 
-def __getattr__(identifier: str) -> object:
-    if re_split(r"[/\\]", stack()[1].filename)[-1] not in (
-        "qg_bot.py",
-        "api.py",
-        "async_api.py",
-        "<frozen importlib._bootstrap>",
-    ):
-        raise AssertionError("此为SDK内部使用文件，无法使用，使用机器人Model库请from model import Model")
-
-    return globals()[identifier.__path__]
-
-
 def api_converter(api: str):
     if api[-2:] in ["()", "（）"]:
         api = api[:-2]
@@ -160,7 +146,7 @@ class _EmptyReturnTemplate:
     message: str
 
 
-def robot():
+def robot_model():
     class Robot:
         id: str
         username: str
