@@ -13,6 +13,14 @@ class Plugins:
         cls._commands, cls._preprocessors = [], []
         return commands, preprocessors
 
+    @classmethod
+    def get_preprocessor_names(cls):
+        return (func.__name__ for func in cls._preprocessors)
+
+    @classmethod
+    def get_commands_names(cls):
+        return (func.__name__ for func in cls._commands)
+
     @classmethod
     def before_command(cls):
         """
